package com.tanpu.community.controller;

import com.tanpu.common.api.CommonResp;
import com.tanpu.common.auth.UserHolder;
import com.tanpu.community.api.beans.TopicBriefInfoDTO;
import com.tanpu.community.api.beans.TopicDTO;
import com.tanpu.community.api.beans.TopicDataAnalysDTO;
import com.tanpu.community.api.beans.req.topic.TopicConcealReq;
import com.tanpu.community.api.beans.req.topic.TopicModifyMountReq;
import com.tanpu.community.api.beans.req.topic.TopicTopReq;
import com.tanpu.community.manager.TopicManager;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.MissingServletRequestParameterException;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@Slf4j
@RequestMapping(value = "/api/admin")
public class AdminController {


    @Autowired
    private TopicManager topicManager;

    @Autowired
    private UserHolder userHolder;

    @GetMapping(value = "/admin/queryTopicDetailList")
    @ApiOperation("查询所有的话题详情")
    @ResponseBody
    public CommonResp<List<TopicBriefInfoDTO>> getAllTopicList(){
        List<TopicBriefInfoDTO> allTopic = topicManager.getAllTopicBriefInfo();
        return CommonResp.success(allTopic);
    }


    @PostMapping(value="/admin/insertTopic")
    @ApiOperation("新增话题")
    @ResponseBody
    public CommonResp<Void> addTopic(@RequestParam String topicTitle){
        String userId = userHolder.getUserId();
        topicManager.insertTopic(topicTitle,userId);
        return CommonResp.success();
    }

    @ApiOperation("单个话题详细数据")
    @PostMapping("/topic/detailData")
    @ResponseBody
    public CommonResp<TopicDTO> selectOne(@RequestParam String topicId) throws MissingServletRequestParameterException {
        if (StringUtils.isEmpty(topicId)){
            throw new MissingServletRequestParameterException("topicId","String");
        }
        TopicDTO topicDTO=topicManager.getDetail(topicId);
        return CommonResp.success(topicDTO);
    }

    @PostMapping(value = "/topic/setTop")
    @ApiOperation("顶置/取消顶置话题")
    @ResponseBody
    public CommonResp<Void> setTopTopic(@RequestBody TopicTopReq req) throws MissingServletRequestParameterException {
        topicManager.setTopTopic(req.getTopicId(),req.isTop());
        return CommonResp.success();
    }

    @PostMapping(value = "/topic/setConceal")
    @ApiOperation("隐藏/显示话题")
    @ResponseBody
    public CommonResp<Void> setConceal(@RequestBody TopicConcealReq req) throws MissingServletRequestParameterException {
        topicManager.setTopicConceal(req.getTopicId(),req.isConceal());
        return CommonResp.success();
    }

    @PostMapping(value = "/topic/modifyViewNum")
    @ApiOperation("话题浏览数调整（后台管理）")
    @ResponseBody
    public CommonResp<Void> modifyViewNum(@RequestBody TopicModifyMountReq req) throws MissingServletRequestParameterException {
        topicManager.modifyViewAmount(req.getTopicId(),req.getModifyMount());
        return CommonResp.success();
    }

    @PostMapping(value = "/topic/dataAnalyse")
    @ApiOperation("话题数据分析")
    @ResponseBody
    public CommonResp<TopicDataAnalysDTO> dataAnalyse(@RequestParam String topicId) throws MissingServletRequestParameterException {
        TopicDataAnalysDTO result =topicManager.queryDataAnalysis(topicId);
        return CommonResp.success(result);
    }
}
