package com.tanpu.community.manager;

import com.tanpu.community.api.beans.req.CreateCommentReq;
import com.tanpu.community.api.beans.req.CreateThemeReq;
import com.tanpu.community.api.beans.ForwardThemeDTO;
import com.tanpu.community.api.beans.qo.ThemeQo;
import com.tanpu.community.api.constants.BlockTypeEnum;
import com.tanpu.community.api.constants.CollectionTypeEnum;
import com.tanpu.community.api.constants.CommentTypeEnum;
import com.tanpu.community.dao.entity.community.*;
import com.tanpu.community.dao.entity.user.CurriculumResEntity;
import com.tanpu.community.dao.entity.user.OrderFlowEntity;
import com.tanpu.community.service.*;
import com.tanpu.community.util.ConvertUtil;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.Duration;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

@Service
public class ThemeManager {
    @Resource
    private ThemeService themeService;

    @Autowired
    private CollectionService collectionService;

    @Autowired
    private CommentService commentService;

    @Autowired
    private FansRelService fansRelService;

    @Autowired
    private BlackListService blackListService;

    @Autowired
    private FinProResService finProResService;

    @Autowired
    private RedisService redisService;

    @Autowired
    private ZhiboService zhiboService;

    @Autowired
    private CurriculumResService curriculumResService;

    @Autowired
    private OrderFlowService orderFlowService;

    @Autowired
    private ThemeAttachmentService themeAttachmentService;

    @Autowired
    private HomePageService homePageService;

    public void createTheme(CreateThemeReq req, String userId) {
        ThemeEntity themeEntity = new ThemeEntity();
        BeanUtils.copyProperties(req,themeEntity);
        themeEntity.setAuthorId(userId);

        themeService.insertTheme(themeEntity);
        List<ThemeAttachmentEntity> themeAttachments = ConvertUtil.themeReqToAttachmentList(req,themeEntity.getId());
        themeAttachmentService.insertList(themeAttachments);

    }
    // 返回推荐主题文章
    public List<ThemeQo> selectHotThemes(String userId) {
        // TODO:根据算法计算推荐主题
        List<ThemeEntity> themeEntities = themeService.selectAll();
        List<ThemeQo> themeQos = ConvertUtil.themeEntitiesToDTOs(themeEntities);
        for (ThemeQo themeQO : themeQos) {
            fillDTOExtraInfo(themeQO, userId);
        }
        return themeQos;
    }


    // 返回关注主题
    public List<ThemeQo> selectInterestThemes(String userId) {
        List<String> fansList = fansRelService.queryFansByFollowerId(userId);
        List<ThemeEntity> themeEntities = themeService.selectByFans(fansList);
        List<ThemeQo> themeQos = ConvertUtil.themeEntitiesToDTOs(themeEntities);
        for (ThemeQo themeQO : themeQos) {
            fillDTOExtraInfo(themeQO, userId);
        }
        return themeQos;
    }

    private String calUpToNowTime(LocalDateTime start) {
        Duration between = Duration.between(LocalDateTime.now(), start);
        long duration = between.toMinutes();
        if (duration < 1) {
            return "刚刚";
        } else if (duration < 60) {
            return duration + "分钟前";
        } else if (duration < 60 * 24) {
            return duration / 60 + "小时前";
        } else if (start.getYear() == LocalDateTime.now().getYear()) {
            return start.format(DateTimeFormatter.ofPattern("MM-dd HH:mm:ss"));
        }
        return start.format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"));
    }

    // 点赞
    public void like(String themeId, String userId) {
        collectionService.addIfNotExist(themeId, userId, CollectionTypeEnum.LIKE);
    }

    public void unlike(String themeId, String userId) {
    }

    // 评论（对主题）
    public void comment(CreateCommentReq req, String userId) {
        CommentEntity commentEntity = CommentEntity.builder()
                .targetId(req.getThemeId())
                .authorId(userId)
                .createBy(userId)
                .content(req.getComment())
                .commentType(CommentTypeEnum.THEME.getCode())
                .build();

        commentService.insertComment(commentEntity);
    }

    //转发
    public void forward(ForwardThemeDTO forwardThemeDTO, String userId) {
        ThemeEntity targetTheme = themeService.selectById(forwardThemeDTO.getFormerThemeId());
        ThemeEntity newTheme = ThemeEntity.builder()
                .content(targetTheme.getContent())
                .formerThemeId(targetTheme.getId())
                .authorId(userId)
                .createBy(userId)
                .build();

        themeService.insertTheme(newTheme);
    }


    //收藏
    public void favorite(String themeId, String userId) {
        collectionService.addIfNotExist(themeId, userId, CollectionTypeEnum.BOOK);
    }

    public void unFavorite(String themeId, String userId) {

    }

    //投诉（主题）
    public void complaint(String themeId, String user) {
        //TODO
    }

    //屏蔽(用户)
    public void blockUser(String themeId, String userId) {
        String blockId = themeService.selectById(themeId).getAuthorId();
        blackListService.addBlock(blockId, userId, BlockTypeEnum.USER);
    }

    // 解除屏蔽(用户)
    public void unblockUser(String themeId, String userId) {
    }

    // 屏蔽(主题)
    public void blockTheme(String themeId, String userId) {
        blackListService.addBlock(themeId, userId, BlockTypeEnum.THEME);
        BlackListEntity selectOne = blackListService.selectOne(userId, BlockTypeEnum.USER.getCode(), themeService.selectById(themeId).getAuthorId());
        if (selectOne == null) {
            blackListService.addBlock(themeService.selectById(themeId).getAuthorId(), userId, BlockTypeEnum.USER);
        }
    }

    // 解除屏蔽(主题)
    public void unblockTheme(String themeId, String userId) {
        blackListService.removeBlackList(themeId, userId, BlockTypeEnum.USER);
    }

    //屏蔽(内容)
//    public void blockContent(String themeId, String userId) {
//        BlackListEntity selectOne = blackListService.selectOne(userId, BlockTypeEnum.USER.getCode(), themeId);
//        if (selectOne==null){
//            blackListService.insertBlackList(userId, BlockTypeEnum.USER.getCode(), themeId);
//        }
//    }



    //查询话题所需关联信息
    private void fillDTOExtraInfo(ThemeQo themeQO, String userId) {
        List<ThemeAttachmentEntity> attachments = themeAttachmentService.selectByThemeId(themeQO.getId());
        if (CollectionUtils.isEmpty(attachments)){
            return;
        }
        List<Object> obs = attachments.stream().map(themeAttachmentEntity -> transferAttachment(themeAttachmentEntity, userId)).collect(Collectors.toList());
        themeQO.setAttachment(obs);
        //是否关注
        themeQO.setUpToNowTime(calUpToNowTime(themeQO.getCreateTime()));
        String authorId = themeQO.getAuthorId();
        Set<String> fansSet = fansRelService.queryFansByFollowerId(userId).stream().collect(Collectors.toSet());
        if (fansSet.contains(authorId)) {
            themeQO.setFollow(true);
        }else {
            themeQO.setFollow(false);
        }
        HomePageEntity userEntity = homePageService.selectByUserId(userId);
        themeQO.setUserImg(userEntity.getHeadImg());
        themeQO.setNickName(userEntity.getNickName());

    }

    public Object transferAttachment(ThemeAttachmentEntity themeAttachment,String userId){
        switch (themeAttachment.getAttachType()) {
            //附件类型 1:产品 2：直播 3：短视频 4：课程
            //TODO ENTITY 转 DTO
            case 1:
                return finProResService.selectById(themeAttachment.getAttchId());
            case 2:
                return zhiboService.selectByid(themeAttachment.getAttchId());
            case 3:
                CurriculumResEntity curriculumResEntity = curriculumResService.selectShortVideo(themeAttachment.getAttchId());
                return curriculumResEntity;
            case 4:
                curriculumResEntity = curriculumResService.selectById(themeAttachment.getAttchId());
                //todo 栏目详情，需要判断当前用户是否购买
                OrderFlowEntity orderFlowEntity = orderFlowService.queryByUserAndProId(themeAttachment.getThemeId(), userId);
                return curriculumResEntity;
            default:
               return null;


        }
    }


}
